%% Initialization
close all
clear all
clc

uh_Vecht_mid = dlmread('uh_Vecht_mid.txt');
uh_Vecht_hig = dlmread('uh_Vecht_hig.txt');
uh_Vecht_low = dlmread('uh_Vecht_low.txt');

% wave conditions
% wave height
Hm0 = 2; 
% peak period
Tp = 5.7; Tm = Tp/1.2; Tm10 = Tp/1.1;

% mean overtopping discharges used for the simulator [m3/m]
q = [0.035 0.1];
n = length(q);

% overtopping volumes used for hydraulic measurement with the simulator
V = [0.5 1 1.5 2 2.5 3 3.5 4 4.5 5 5.5 6];
m = length(V);

    PV = zeros(m,n);
    
    Povx = zeros(m,n);
    
    Rux = zeros(m,n);
    
    % at the seaward crest edge
    hA2 = zeros(m,n); uA2 = zeros(m,n);
    
    % at the landward crest edge, xB = 3m
    hB2 = zeros(m,n); uB2 = zeros(m,n);
    
    % at sC = 4 m
    hyC1 = zeros(m,n); uyC1 = zeros(m,n);

%% constants
% acceleration due to gravity [m/s2]
    g = 9.81; 

% coefficients in calculating Ru2% and q wrt probabilistic design
    c1 = 1.65; c2 = 4.75;

% landward-side slope
    tan_alpha = 1/4; sin_alpha = sin(atan(1/4)); cos_alpha = cos(atan(1/4));

% landward-side slope
sin_beta1 = 1/4; cos_beta1 = cos(asin(sin_beta1));
sin_beta2 = 1.5/8; cos_beta2 = cos(asin(sin_beta2));


% coefficient at the seaward edge crest
cAh = 1.1; cAu = 0.88;

% coefficient on the crest
    aBh = 0.8; bBh = -1;
    aBu = 1.1; bBu = -1.8;
    
    fBh = 0.05; fBu = 0.2;

% coefficient on the landward-side slope
    aCh = 0.64; bCh = -1.4;
    aCu = 0.46; bCu = 0.24;
    
    fCh = 0.1; fCu = 0.2;  % friction coefficients

% crest width, the simulator was positioned 3 m from the crest edge
    B = 3; 

% position on the landward-side slope
    sC1 = 4; sC2 = 8;

%% calculations
    
    % wave length wrt Tm-1,0
    Lm_10 = g*(Tm10^2)/2/pi;
    % wave steepness
        s0 = 2*pi/g*Hm0/(Tm10^2);
    % surf similarity parameter xi_0
        xi0 = tan_alpha/(sqrt(s0));      
        
    % 2% wave run-up
        Ru2per = c1*xi0*Hm0;

  
for i = 1:n            
        % crest freeboard Rc [m] derived from q
        Rc = 1/(-c2)*Hm0*xi0*log(q(i)/0.067/xi0*sqrt(tan_alpha/(g*(Hm0^3))));
        
        % probability of overtopping Pov
        Povt = exp(-((sqrt(-log(0.02))*Rc/Ru2per)^2));
        
        % scale factor
        a = 0.84*Tm*q(i)/Povt;
        
        
        for j = 1:m

            % exceedance probability PV of an overtopping volume per wave
            PV(j,i) = 1 - exp(-((V(j)/a)^0.75));

            % overtopping probability Povx associated with volume V
            Povx(j,i) = (1 - PV(j,i))*Povt;

            % freeboard associated with volume V
            Rux(j,i) = Ru2per*sqrt(log(Povx(j,i))/log(0.02));

            % water-layer thickness at the seaward crest edge hA2%
            hA2(j,i) = cAh*sin_alpha*V(j)/(Rux(j,i) - Rc)/Hm0;
            % flow velocity  at the seaward crest edge uA2%
            uA2(j,i) = cAu*cos_alpha/Hm0*sqrt(V(j)/sin_alpha);
            
            % at the landward crest edge xB = B
            hB2(j,i) = aBh*hA2(j,i)*exp(bBh*B/Lm_10)*(1+fBh);
            uB2(j,i) = aBu*uA2(j,i)*exp(bBu*B/Lm_10)*(1-fBu);
            
            % at the position sC = 4 m
            hyC1(j,i) = hB2(j,i)*aCh*exp(bCh*sC1*cos_beta1/Lm_10)*(1+fCh);
            uyC1(j,i) = exp(aCu*uB2(j,i))*exp(bCu*sC1*cos_beta1/Lm_10)*(1-fCu);

        end
end

%% figure 1 showing flow depth
 figure1 = figure('Name','Flow depth hyC2% at sC = 3 m vs. overtopping volume');
    set(figure1,'PaperUnits','points');

    xSize = 320; ySize = 190;

    % additional coordinates to locate the figure on A4-paper
    xLeft = (597-xSize)/2; yTop = (845-ySize)/2;

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure1,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure1,'Position', [xLeft yTop xSize*2 ySize*2]);

    x = 45/xSize; y = 35/ySize; 

    % Figure dimensions are 142 pt wide and 106.3 pt high
    width = 230/xSize; height = 127/ySize;

    % Create axes
    axes1 = axes('Parent', figure1, 'position', [x y width height]);
    set(axes1,'XMinorGrid','off');

    % Create xlabel
    xlabel('V/H_{m0}^2');
    % Create ylabel
    ylabel('h_{y_C,2%}/H_{m0}');

    % X-limits of the axes
    xlim(axes1,[0 2]);
    % Y-limits of the axes
    ylim(axes1,[0 0.25]);
    
    % Create title
    title1 = title(axes1,'Landward slope s_c = 4 m and f_C^h = 0.1');
    
    box(axes1,'on');
    hold(axes1,'all');
    
% Flowdike test
plot1 = plot(V/(Hm0^2), hyC1(:,1),'Parent',axes1,'LineStyle','-','Color',[0 0 0]);
plot5 = plot(V/(Hm0^2), hyC1(:,2),'Parent',axes1,'LineStyle','-.','Color',[0 0 0]);

plot2 = plot(uh_Vecht_hig(:,1)/(Hm0^2), uh_Vecht_hig(:,4)/Hm0,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot2,'Marker','^');
plot3 = plot(uh_Vecht_mid(:,1)/(Hm0^2), uh_Vecht_mid(:,4)/Hm0,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot3,'Marker','^');
plot4 = plot(uh_Vecht_low(:,1)/(Hm0^2), uh_Vecht_low(:,4)/Hm0,'Parent',axes1,'LineStyle','none','Color',[0 0 0]);
set(plot4,'Marker','^');

% range of application
plot6 = plot([0.89 0.89], [0 0.25],'Parent',axes1);
set(plot6,'Color','Black');


% Create legend
    legend1 = legend(axes1,'35 l/s per m','100 l/s per m', 'SB3');
    set(legend1,'Location','EastOutside');

% print figure as an eps file    
    print('-depsc','-tiff','-r600', 'hsC4_Vechtf01'); 
    
 % figure 2 linear relation
figure2 = figure('Name','Flow velocity uyC2% at sC = 3 m vs. overtopping volume');
    set(figure2,'PaperUnits','points');

    % set the position and size of the figure on the paper to the desired
    % values
    set(figure2,'PaperPosition', [xLeft yTop xSize ySize]);

    % reset the size and position of the figure window on the computer screen
    set(figure2,'Position', [xLeft yTop xSize*2 ySize*2]);

    % Create axes
    axes2 = axes('Parent', figure2, 'position', [x y width height]);
    set(axes2,'XMinorGrid','off');

    % Create xlabel
    xlabel('V/H_{m0}^2');
    % Create ylabel
    ylabel('u_{y_C,2%}/(gH_{m0})^{0.5}');
    
    % X-limits of the axes
    xlim(axes2,[0 2]);
    % Y-limits of the axes
    ylim(axes2,[0 2.5]);
    
     % Create title
    title2 = title(axes2,'Landward slope s_C = 4 m and f_C^u = 0.2');
    
    box(axes2,'on');
    hold(axes2,'all');
    
    % Flowdike test
plot7 = plot(V/(Hm0^2), uyC1(:,1),'Parent',axes2,'LineStyle','-','Color',[0 0 0]);
plot11 = plot(V/(Hm0^2), uyC1(:,2),'Parent',axes2,'LineStyle','-.','Color',[0 0 0]);

plot8 = plot(uh_Vecht_hig(:,1)/(Hm0^2), uh_Vecht_hig(:,8)/sqrt(g*Hm0),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot8,'Marker','square');
plot9 = plot(uh_Vecht_low(:,1)/(Hm0^2), uh_Vecht_low(:,7)/sqrt(g*Hm0),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot9,'Marker','x');
plot10 = plot(uh_Vecht_low(:,1)/(Hm0^2), uh_Vecht_low(:,8)/sqrt(g*Hm0),'Parent',axes2,'LineStyle','none','Color',[0 0 0]);
set(plot10,'Marker','square');

% range of application
plot12 = plot([0.89 0.89], [0 2.5],'Parent',axes2);
set(plot12,'Color','Black');

% Create legend
    legend2 = legend(axes2,'35 l/s per m','100 l/s per m', 'PW3b', 'PW3a');
    set(legend2,'Location','EastOutside');

% print figure as an eps file    
     print('-depsc','-tiff','-r600', 'usC4_Vechtf02');  
     
    